Package: cellmig
Type: Package
Title: Uncertainty-aware quantitative analysis of high-throughput live
        cell migration data
Version: 1.0.0
Authors@R: c(
    person("Simo", "Kitanovski", email = "simokitanovski@gmail.com", 
    role = c("aut", "cre"), comment=c(ORCID="0000-0003-2909-5376")))
Description: High-throughput cell imaging facilitates the analysis of cell 
    migration across many wells treated under different biological conditions. 
    These workflows generate considerable technical noise and biological 
    variability, and therefore technical and biological replicates are 
    necessary, leading to large, hierarchically structured datasets, i.e., 
    cells are nested within technical replicates that are nested within 
    biological replicates. Current statistical analyses of such data usually 
    ignore the hierarchical structure of the data and fail to explicitly 
    quantify uncertainty arising from technical or biological variability. 
    To address this gap, we present cellmig, an R package implementing Bayesian 
    hierarchical models for migration analysis. cellmig quantifies condition-
    specific velocity changes (e.g., drug effects) while modeling nested data 
    structures and technical artifacts. It further enables synthetic data 
    generation for experimental design optimization. 
License: GPL-3 + file LICENSE
Depends: R (>= 4.5.0)
Imports: base, ggplot2, ggforce, ggtree, patchwork, ape, methods, Rcpp
        (>= 0.12.0), RcppParallel (>= 5.0.1), reshape2, rstan (>=
        2.18.1), rstantools (>= 2.4.0), stats, utils, scales
Suggests: BiocStyle, knitr, testthat
Encoding: UTF-8
NeedsCompilation: yes
biocViews: SingleCell, CellBiology, Bayesian, ExperimentalDesign,
        Software, BatchEffect, Regression, Clustering
BugReports: https://github.com/snaketron/cellmig/issues
URL: https://github.com/snaketron/cellmig
RoxygenNote: 7.3.1
VignetteBuilder: knitr
Biarch: true
LinkingTo: BH (>= 1.66.0), Rcpp (>= 0.12.0), RcppEigen (>= 0.3.3.3.0),
        RcppParallel (>= 5.0.1), rstan (>= 2.18.1), StanHeaders (>=
        2.18.0)
SystemRequirements: GNU make
git_url: https://git.bioconductor.org/packages/cellmig
git_branch: RELEASE_3_22
git_last_commit: e77030e
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-30
Packaged: 2025-10-30 20:52:11 UTC; biocbuild
Author: Simo Kitanovski [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2909-5376>)
Maintainer: Simo Kitanovski <simokitanovski@gmail.com>
