# Generated by roxygen2: do not edit by hand
export(cellmig)
export(get_dose_response_profile)
export(gen_partial)
export(gen_full)
export(get_ppc_violins)
export(get_ppc_means)
export(get_pairs)
export(get_violins)
export(get_groups)
import(utils)
import(Rcpp)
import(methods)
import(ggplot2)
importFrom(ape, as.phylo)
importFrom(ape, prop.clades)
importFrom(ape, is.rooted)
importFrom(ggforce, geom_sina)
importFrom(rstan, sampling)
importFrom(rstan, summary)
importFrom(rstan, extract)
importFrom(rstantools, rstan_config)
importFrom(reshape2, acast)
importFrom(reshape2, melt)
importFrom(RcppParallel, RcppParallelLibs)
importFrom(stats, dist, hclust, aggregate, rgamma, rnorm)
importFrom(scales, pretty_breaks)
importFrom(ggtree, ggtree, geom_point2, geom_tippoint, geom_tiplab, 
           geom_nodelab, layout_rectangular, revts)
importFrom(patchwork, plot_layout, plot_annotation)
useDynLib(cellmig, .registration = TRUE)